@@ -6,6 +6,8 @@ as part of the RPIO package by Chris Hager <chris@linuxuser.at>.
 URL: https://github.com/metachris/RPIO
 License: c_gpio.c is released under the MIT License
 
+Internally everything works with BCM gpio numbering mode!
+
 Changes:
 - PEP7 cleanup
 - Added some documentation
@@ -19,17 +21,19 @@ Changes:
 
 #define BCM2708_PERI_BASE   0x20000000
 #define GPIO_BASE           (BCM2708_PERI_BASE + 0x200000)
-#define FSEL_OFFSET         0   // 0x0000
-#define SET_OFFSET          7   // 0x001c / 4
-#define CLR_OFFSET          10  // 0x0028 / 4
-#define PINLEVEL_OFFSET     13  // 0x0034 / 4
-#define EVENT_DETECT_OFFSET 16  // 0x0040 / 4
-#define RISING_ED_OFFSET    19  // 0x004c / 4
-#define FALLING_ED_OFFSET   22  // 0x0058 / 4
-#define HIGH_DETECT_OFFSET  25  // 0x0064 / 4
-#define LOW_DETECT_OFFSET   28  // 0x0070 / 4
-#define PULLUPDN_OFFSET     37  // 0x0094 / 4
-#define PULLUPDNCLK_OFFSET  38  // 0x0098 / 4
+#define OFFSET_FSEL         0   // 0x0000
+#define OFFSET_SET          7   // 0x001c / 4
+#define OFFSET_CLR          10  // 0x0028 / 4
+#define OFFSET_PINLEVEL     13  // 0x0034 / 4
+#define OFFSET_PULLUPDN     37  // 0x0094 / 4
+#define OFFSET_PULLUPDNCLK  38  // 0x0098 / 4
+
+// Event detection offsets disabled for now
+//#define OFFSET_EVENT_DETECT 16  // 0x0040 / 4
+//#define OFFSET_RISING_ED    19  // 0x004c / 4
+//#define OFFSET_FALLING_ED   22  // 0x0058 / 4
+//#define OFFSET_HIGH_DETECT  25  // 0x0064 / 4
+//#define OFFSET_LOW_DETECT   28  // 0x0070 / 4
 
 #define PAGE_SIZE  (4*1024)
 #define BLOCK_SIZE (4*1024)
@@ -74,20 +78,20 @@ setup(void)
 void
 set_pullupdn(int gpio, int pud)
 {
-    int clk_offset = PULLUPDNCLK_OFFSET + (gpio/32);
+    int clk_offset = OFFSET_PULLUPDNCLK + (gpio/32);
     int shift = (gpio%32);
 
     if (pud == PUD_DOWN)
-       *(gpio_map+PULLUPDN_OFFSET) = (*(gpio_map+PULLUPDN_OFFSET) & ~3) | PUD_DOWN;
+       *(gpio_map+OFFSET_PULLUPDN) = (*(gpio_map+OFFSET_PULLUPDN) & ~3) | PUD_DOWN;
     else if (pud == PUD_UP)
-       *(gpio_map+PULLUPDN_OFFSET) = (*(gpio_map+PULLUPDN_OFFSET) & ~3) | PUD_UP;
+       *(gpio_map+OFFSET_PULLUPDN) = (*(gpio_map+OFFSET_PULLUPDN) & ~3) | PUD_UP;
     else  // pud == PUD_OFF
-       *(gpio_map+PULLUPDN_OFFSET) &= ~3;
+       *(gpio_map+OFFSET_PULLUPDN) &= ~3;
 
     short_wait();
     *(gpio_map+clk_offset) = 1 << shift;
     short_wait();
-    *(gpio_map+PULLUPDN_OFFSET) &= ~3;
+    *(gpio_map+OFFSET_PULLUPDN) &= ~3;
     *(gpio_map+clk_offset) = 0;
 }
 
@@ -96,7 +100,7 @@ set_pullupdn(int gpio, int pud)
 void
 setup_gpio(int gpio, int direction, int pud)
 {
-    int offset = FSEL_OFFSET + (gpio/10);
+    int offset = OFFSET_FSEL + (gpio/10);
     int shift = (gpio%10)*3;
 
     set_pullupdn(gpio, pud);
@@ -111,7 +115,7 @@ setup_gpio(int gpio, int direction, int pud)
 int
 gpio_function(int gpio)
 {
-    int offset = FSEL_OFFSET + (gpio/10);
+    int offset = OFFSET_FSEL + (gpio/10);
     int shift = (gpio%10)*3;
     int value = *(gpio_map+offset);
     value >>= shift;
@@ -125,9 +129,9 @@ output_gpio(int gpio, int value)
 {
     int offset;
     if (value) // value == HIGH
-        offset = SET_OFFSET + (gpio / 32);
+        offset = OFFSET_SET + (gpio / 32);
     else       // value == LOW
-        offset = CLR_OFFSET + (gpio / 32);
+        offset = OFFSET_CLR + (gpio / 32);
     *(gpio_map+offset) = 1 << gpio % 32;
 }
 
@@ -136,7 +140,7 @@ int
 input_gpio(int gpio)
 {
    int offset, value, mask;
-   offset = PINLEVEL_OFFSET + (gpio/32);
+   offset = OFFSET_PINLEVEL + (gpio/32);
    mask = (1 << gpio%32);
    value = *(gpio_map+offset) & mask;
    return value;
